<div id="search" role="search">          
    {%- if builder != 'singlehtml' %}
        <form id="rtd-search-form" class="wy-form" action="{{ pathto('search') }}" method="get">
            <input type="text" name="q" placeholder="{{ _('Search...') }}" />
            <input type="hidden" name="check_keywords" value="yes" />
            <input type="hidden" name="area" value="default" />
        </form>
   {%- endif %}
</div>