<!DOCTYPE html>
<head>
  <meta charset="utf-8">
  {{ metatags }}
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  {% block htmltitle %}
  <title>{{ project }} :: {{ title|striptags|e }}{{ titlesuffix }}</title>
  {% endblock %}

  <link rel="icon" type="image/png" sizes="32x32" href="{{ pathto('_static/img/favicon-32x32.png', 1) }}">
  <link rel="icon" type="image/png" sizes="16x16" href="{{ pathto('_static/img/favicon-16x16.png', 1) }}">

  {%- if hasdoc('genindex') %}
        <link rel="index" title="{{ _('Index') }}"
              href="{{ pathto('genindex') }}"/>
    {%- endif %}

  <link rel="stylesheet" href="{{ pathto('_static/css/insegel.css', 1) }}"/>
  <link rel="stylesheet" href="{{ pathto('_static/css/gruvbox.css', 1) }}" type="text/css" />

  <script type="text/javascript">
    var DOCUMENTATION_OPTIONS = {
        URL_ROOT: '{{ url_root }}',
        VERSION: '{{ release|e }}',
        LANGUAGE: '{{ language }}',
        COLLAPSE_INDEX: false,
        FILE_SUFFIX: '{{ '' if no_search_suffix else file_suffix }}',
        HAS_SOURCE: {{ has_source|lower }},
        SOURCELINK_SUFFIX: '{{ sourcelink_suffix }}'
    };
  </script>

  {%- for scriptfile in script_files %}
    <script type="text/javascript" src="{{ pathto(scriptfile, 1) }}"></script>
  {%- endfor %}
</head>

<body>
  <div id="insegel-container">
    <header>
      <div id="logo-container">
          {% if logo %}
          <a href="{{ pathto(master_doc) }}"><img src="{{ pathto('_static/' + logo, 1) }}"></a>
          {% else %}
          <a href="{{ pathto(master_doc) }}"><img src="{{ pathto('_static/img/logo.svg', 1) }}"></a>
          {% endif %}

      </div>
      <div id="project-container">
        <h1>{{ project }} Documentation</h1>
      </div>
    </header>

    <div id="content-container">

      <div id="main-content-container">
        <div id="main-content">
          {% block body %}{% endblock %}
        </div>
      </div>

      <div id="side-menu-container">

        {% include "searchinput.html" %}

        <div id="side-menu" role="navigation">

          {% include "menu.html" %}

        </div>

      </div>

    </div>

{% include "footer.html" %}

{%- block footer %} {% endblock %}

</div>

</body>
</html>
