<footer>
    <div id="footer-info">
        <ul id="build-details">
            {% if hasdoc(pagename) %}
                <li class="footer-element">
                    {% if display_github %}
                        <a href="https://{{ github_host|default("github.com") }}/{{ github_user }}/{{ github_repo }}/blob/{{ github_version }}{{ conf_py_path }}{{ pagename }}{{ page_source_suffix }}"> {{ _('source') }}</a>
                    {% elif show_source and source_url_prefix %}
                        <a href="{{ source_url_prefix }}{{ pagename }}{{ suffix }}">{{ _('source') }}</a>
                    {% elif show_source and has_source and sourcename %}
                        <a href="{{ pathto('_sources/' + sourcename, true)|e }}" rel="nofollow"> {{ _('source') }}</a>
                    {% endif %}
                </li>
            {% endif %}

            {% if commit %}
                <li class="footer-element">
                    <a href="https://{{ github_host|default("github.com") }}/{{ github_user }}/{{ github_repo }}/commit/{{commit}}">{{ commit }}</a>
                </li>
            {% endif %}

            {% if last_updated %}
                <li class="footer-element">
                    {{ last_updated }}
                </li>
            {% endif %}
        </ul>

        {% if copyright %}
            <div id="copyright">
                <p>&copy; {{ copyright }}</p>
            </div>
        {% endif %}
    </div>

    <a id="menu-toggle" class="fa fa-bars" aria-hidden="true"></a>

    <script type="text/javascript">
      $("#menu-toggle").click(function() {
        $("#menu-toggle").toggleClass("toggled");
        $("#side-menu-container").slideToggle(300);
      });
    </script>

</footer>
