@import url('https://fonts.googleapis.com/css2?family=Open+Sans');
@import url("https://fonts.googleapis.com/css?family=Inconsolata");
/* http://meyerweb.com/eric/tools/css/reset/
   v2.0 | 20110126
   License: none (public domain)
*/
:root {
  --bg: #282828;
  --bg_s: #32302f;
  --bg_h: #1d2021;
  --bg1: #3c3836;
  --bg2: #504945;
  --bg3: #665c54;
  --fg1: #ebdbb2;
  --fg2: #d5c4a1;
  --red: #fb4934;
  --blue: #83a598;
}

::-webkit-scrollbar {
  background-color: var(--bg_h);
  max-width: 0.75em;
  max-height: 0.75em;
}

::-webkit-scrollbar-corner {
  background-color: var(--bg_s);
}

::-webkit-scrollbar-thumb {
  background-color: #665c54;
}

::-webkit-scrollbar-thumb:hover {
  background-color: #7c6f64;
}

html {
  font-family: 'Inconsolata', monospace;
}

h1, h2, h3, h4, h5, h6 {
  font-family: 'Open Sans', sans-serif;
  color: var(--fg1);
}

p, a, li, i, b {
  color: var(--fg2);
}

/* HTML5 display-role reset for older browsers */
article, aside, details, figcaption, figure,
footer, header, hgroup, menu, nav, section {
  display: block;
}

body {
  line-height: 1;
  background-color: var(--bg_s);
}

header {
  padding-top: 2em;
  margin-bottom: 2.25em;
  display: flex;
}
header #logo-container {
  width: 300px;
  padding-left: 2em;
  display: flex;
  align-items: center;
}
@media screen and (max-width: 1000px) {
  header #logo-container {
    width: 250px;
  }
}
@media screen and (max-width: 880px) {
  header #logo-container {
    width: 100%;
    padding: 0;
    display: block;
  }
}
header #logo-container img {
  height: 60px;
}
header #project-container {
  padding: 0em 2em;
}
@media screen and (max-width: 880px) {
  header {
    text-align: center;
    display: block;
  }
}

ol, ul {
  list-style: none;
}

blockquote, q {
  quotes: none;
}

blockquote:before, blockquote:after,
q:before, q:after {
  content: '';
  content: none;
}

table {
  border-collapse: collapse;
  border-spacing: 0;
}

a {
  text-decoration: none;
  color: inherit;
  font-weight: 500;
  border-bottom: 2px solid transparent;
  transition: border-bottom 0.25s;
}
a.headerlink {
  border-bottom: 0;
}

a:hover:not(.headerlink) {
  border-bottom: 2px solid var(--fg1);
}

p {
  margin-bottom: 1em;
}

em {
  font-style: italic;
}

strong {
  font-weight: bold;
}

li {
  display: list-item;
}

ol {
  display: block;
  list-style-type: decimal;
  padding-left: 40px;
}

ul {
  display: block;
  list-style-type: disc;
  padding-left: 25px;
}

ul ul {
  list-style-type: circle;
}

pre {
  font-family: "Inconsolata", monospace;
  background-color: var(--bg2);
  padding: 2em;
  margin-bottom: 1em;
  overflow-x: auto;
}

.literal-block {
  color: var(--fg1);
}

img {
  max-width: 100%;
}

table {
  margin: 0 0 1.5em;
  width: 100%;
  max-width: 100%;
}

table thead th {
  font-weight: bold;
  text-align: left;
}

table th, table td {
  padding: 0.5em;
}

table tbody tr:nth-of-type(odd) {
  background-color: var(--bg1);
  color: var(--fg1);
}

pre code {
  white-space: nowrap;
  overflow-x: auto;
}

code {
  max-width: 100%;
  padding: 2px;
  font-family: "Inconsolata", monospace;
  background-color: var(--bg2);
  color: var(--fg1);
}

table tbody tr:nth-of-type(odd) code {
  background-color: var(--bg);
  color: var(--fg1);
}

#copyright p {
  font-size: 1em;
}

#insegel-container {
  padding-left: 1em;
  padding-right: 1em;
  max-width: 1300px;
  margin-left: auto;
  margin-right: auto;
}
@media screen and (max-width: 880px) {
  #insegel-container {
    padding: 0;
  }
}

#content-container {
  display: flex;
  width: 100%;
  flex-direction: row-reverse;
}
@media screen and (max-width: 880px) {
  #content-container {
    display: block;
  }
}

#main-content-container {
  flex: 1;
  width: 0;
}

@media screen and (max-width: 880px) {
  #main-content-container {
    width: inherit;
  }
}

#main-content-container, #side-menu-container {
  background-color: var(--bg1);
}

#main-content {
  padding: 2em;
  padding-top: 0em;
}

#main-content .figure {
  text-align: center;
}

#side-menu-container {
  width: 300px;
  margin-right: 2em;
  position: relative;
}
#side-menu-container #side-menu {
  padding: 2em;
  margin-bottom: 5em;
}
#side-menu-container #rtd-credit {
  padding: 2em;
  position: absolute;
  bottom: 0;
}
@media screen and (max-width: 1000px) {
  #side-menu-container {
    width: 250px;
  }
}
@media screen and (max-width: 880px) {
  #side-menu-container {
    margin-right: 0;
    width: 100%;
    display: none;
  }
  #side-menu-container #side-menu {
    margin-bottom: 0;
  }
  #side-menu-container #rtd-credit {
    position: relative;
  }
}

a.headerlink {
  display: none;
  visibility: hidden;
}
a.headerlink:after {
  visibility: visible;
  font: normal normal normal 14px/1 FontAwesome;
  font-size: inherit;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  content: "\f0c1";
  display: inline-block;
  opacity: 0.6;
}

h1:hover .headerlink, h2:hover .headerlink, h3:hover .headerlink, h4:hover .headerlink, h5:hover .headerlink, h6:hover .headerlink, dl dt:hover .headerlink, p.caption:hover .headerlink {
  display: inline-block;
}

#side-menu .local-toc ul {
  text-transform: uppercase;
  font-weight: 300;
  padding-left: 0px;
  list-style-type: none;
}
#side-menu .local-toc ul ul {
  margin-top: 1em;
  text-transform: none;
}
#side-menu .local-toc ul ul a {
  font-weight: 400;
}
#side-menu .caption {
  opacity: 0.7;
  font-weight: 300;
  list-style-type: none;
  margin-bottom: 0px;
}
#side-menu ul {
  margin-bottom: 1em;
  text-transform: none;
  list-style-type: none;
  padding-left: 0px;
}
#side-menu .toctree-12 > a {
  font-weight: normal;
  margin-left: 1em;
}
#side-menu .toctree-l3 > a, #side-menu .toctree-l4 > a, #side-menu .toctree-l5 > a {
  font-weight: normal;
  opacity: 0.7;
  margin-left: 2em;
}

#search input[type=text] {
  width: 100%;
  font-weight: 200;
  font-size: 1.25em;
  box-sizing: border-box;
  border: none;
  background-color: var(--bg2);
  color: var(--fg1);
  font-family: "Inconsolata", monospace;
}
#search input[type=text]::placeholder {
  color: var(--fg2);
  font-weight: 200;
}

.admonition {
  padding: 2em;
  margin-bottom: 2em;
  background-color: var(--bg1);
  color: var(--fg1);
}
.admonition .admonition-title {
  font-weight: 500;
}
.admonition.warning, .admonition.caution, .admonition.danger, .admonition.error {
  background-color: var(--red);
  color: var(--fg1);
}
.admonition.attention, .admonition.important {
  background-color: var(--blue);
  color: var(--fg1);
}

.injected {
  display: none;
}

.toctree-wrapper {
  margin-bottom: 1em;
}
.toctree-wrapper .caption-text {
  font-weight: 300;
  opacity: 0.5;
}

.figure {
  margin-bottom: 1em;
}

footer {
  display: flex;
  justify-content: space-between;
  margin: 2em;
}
footer #footer-info {
  display: flex;
  justify-content: space-between;
  width: 100%;
}
footer a#menu-toggle {
  display: none;
  opacity: 1;
  font-size: 32px;
  cursor: pointer;
}
footer a#menu-toggle.toggled {
  color: var(--bg1);
}
footer ul#build-details {
  list-style: none;
  display: flex;
  margin: 0;
  padding: 0;
}
footer ul#build-details li {
  margin-right: 0.25em;
}
footer ul#build-details li:not(:last-child):after {
  content: " // ";
  margin-left: 0;
}
@media screen and (max-width: 880px) {
  footer {
    align-items: center;
  }
  footer #footer-info {
    display: block;
  }
  footer a#menu-toggle {
    display: block;
  }
}

#search-results ul.search {
  padding-left: 0px;
  list-style-type: none;
}
#search-results ul.search li {
  margin-bottom: 2em;
}
#search-results ul.search .context {
  margin-top: 1em;
  white-space: pre-line;
  background-color: var(--bg1);
  color: var(--fg1);
  padding: 2em;
}
#search-results ul.search .context .highlighted {
  font-weight: 800;
}

dl:not(.docutils) dd {
  margin-left: 2em;
}
dl:not(.docutils) dd dl {
  margin-bottom: 1em;
}
dl:not(.docutils) dt {
  background: var(--bg1);
  color: var(--fg1);
  padding: 0.5em;
  padding-right: 0.75em;
  margin-bottom: 1em;
  display: inline-block;
}
dl:not(.docutils) dt .property {
  margin-right: 0.5em;
}
dl:not(.docutils) dt code {
  background: var(--bg1);
  color: var(--fg1);
  font-weight: bold;
  padding: 0px;
}
dl:not(.docutils) dl dt {
  background: var(--bg1);
  color: var(--fg1);
  border-left: 0.25em solid var(--fg1);
}
dl:not(.docutils) dl dt code {
  background: var(--bg1);
  color: var(--fg1);
}

/* Comment */
.err {
  border: 1px solid var(--red);
}


/* Literal.String.Char */
.sd, .s2, .se, .sh, .si, .sx, .sr, .s1, .ss, .sc, .sb, .s, .ge, .cs, .c1, .cm, .c {
  font-style: italic;
}

.se, .si, .ow, .nt, .nn, .ne, .ni, .nc, .kr, .kn, .kd, .kc, .gu, .gs, .gp, .gh, .k {
  font-weight: bold;
}
